from Freya_alerce.core.commands.base_freya import Base

class RenameCatalog(Base):
    """
    Rename catalog inside Freya.

    Parameters
    ----------
    old_name : (string) 
        name catalog inside Freya.
    new_name : (string) 
        new name for catalog inside Freya.
    """
    def __init__(self,**kwargs):
        super().__init__(**kwargs)
        super().rename_catalog()


import tempfile
import os

from unittest import TestCase,mock
from Freya_alerce.core.commands.base_api import BaseAPI
from Freya_alerce.files.list_file import ListFiles
from Freya_alerce.files.verify_file import Verify

class TestAddResource(TestCase):
    
    def setUp(self):
        self.temp_FreyaAPI = tempfile.TemporaryDirectory()

    def test(self):
        BaseAPI(path=self.temp_FreyaAPI.name).create_new_api()
        path_api = os.path.join(self.temp_FreyaAPI.name,'FreyaAPI')
        BaseAPI(name='ztf',path=path_api).create_new_resource()
        path_resource = os.path.join(path_api,'app/main/resources_freya/ZTF_resource')
        self.assertTrue(os.path.isdir(path_resource))
        

    def tearDown(self):
        self.temp_FreyaAPI.cleanup()

if __name__ == '__main__':
    unittest.main() 


import pandas as pd
import io

from astropy.io.votable import from_table, writeto
from astropy.io.votable.tree import VOTableFile, Table
from astropy.table import Table, Column

class FormatLC(object):
    """
    Parameters
    ----------
    data_np : numpy array 2d
        input is numpy array 2d, each column is a feature (['obj','ra','dec','mjd','mag',''magerr,'filter','catalog']), each column is an observation of a object.
    """

    def __init__(self,data_np):
        self.data_np = data_np

    def format_numpy(self):
        """
        Return
        -------
        Return data who numpy matrix.
        """
        return self.data_np

    def format_csv(self):
        """
        Return
        -------
        Return data in CSV format.
        """
        df = pd.DataFrame({'obj':self.data_np[:,0],'ra':self.data_np[:,1],
                            'dec':self.data_np[:,2],'mjd':self.data_np[:,3],
                            'mag':self.data_np[:,4],'magerr':self.data_np[:,5],
                            'filter':self.data_np[:,6],'catalog':self.data_np[:,7]})
        return df.to_csv(index=False)

    def format_votable(self):
        """
        Return
        -------
        Return data in VOTable format.
        """
        names_column = ['obj','ra','dec','mjd','mag','magerr','filter','catalog']
        descriptions_column = ['Id of object in catalog the original catalog',
                                'Right ascension of source','Declination of source',
                                'Julian Day','Magnitude','Magnitude Error',
                                'Filter code','Original Catalog']
        #dtype_column = [] # dtype=dtype_column
        t = Table(rows=self.data_np,names=names_column,descriptions=descriptions_column)
        votable= VOTableFile.from_table(t)
        buf = io.BytesIO()
        writeto(votable,buf)
        return buf.getvalue().decode("utf-8")


from Freya_alerce.core.commands.base_api import BaseAPI


class AddResource(BaseAPI):
    """
    Add resource to FreyaAPI, need call inside FreyaAPI.

    Parameters
    ----------
    name : (string) 
        name catalogue in Freya what adds resource in FreyaAPI.
    """
    def __init__(self,**kwargs):
        super().__init__(**kwargs)
        super().create_new_resource()


import os
import tempfile
import shutil
import zipfile #read zip files
import Freya_alerce.files # __path_
from Freya_alerce.files.verify_file import Verify
from Freya_alerce.files.list_file import ListFiles


class Base(object):
    """
    Base class to command line Freya, contains method for add new catalog inside Freya or in local folder, 
    created new local folder.

    Parameters
    --------------------------------------
    name : (string) 
        name with add catalog inside Freya or in local folder.
    source : (string) 
        origin source catalog [api,db]
    path : (string) 
        path where created catalogs.
    """

    def __init__(self,**kwargs):
        self.name = kwargs.get('name')
        if self.name:
            #self.name = self.name.replace(self.name[0],self.name[0].upper(),1)
            self.name = self.name.upper()
        self.new_name = kwargs.get('new_name')
        if self.new_name:
            self.new_name = self.new_name.upper()
        self.source = kwargs.get('source')
        self.path = kwargs.get('path')
    
    def create_module_catalog(self):
        """
        Create new catalog module inside Freya,
        first verify if source catalog is valid, 
        second verify the catalog already exist then get path
        for new module catalog and path template data,
        finaly try create the new module folder and extract the data.
        """
        
        #self.name= self.name.upper()
        if not Verify().verify_source(self.source):
            raise TypeError (f'The source not is valid')

        if Verify().verify_catalog_inside(self.name) or Verify().verify_catalog_local(self.name):  
            raise TypeError ('catalog already created')
        
        path_dir = self.path
        path_new_catalog = os.path.join(path_dir,self.name)
        path_tample_files_ = ListFiles().path_files__from_()     
        try: 
            with tempfile.TemporaryDirectory() as tmpdir:
                #print('created temporary directory', tmpdirname)
                extract_zip = zipfile.ZipFile(path_tample_files_)
                if self.source == 'api' or self.source == 'other':
                    list_names_files = ListFiles().files_api()
                elif self.source == 'db':
                    list_names_files = ListFiles().files_db()
                for file_ in list_names_files:
                    extract_zip.extract(file_, tmpdir)
                extract_zip.close()
                # Replace word 'NAME' from the name catalog
                if self.source == 'api' or self.source == 'other':
                    list_path = [os.path.join(tmpdir,f) for f in ListFiles().files_api()]
                    ListFiles().replace_in_files(list_path,'from Freya_alerce.catalogs.NAME import ConnectNAME','')
                elif self.source == 'db':
                    list_path = [os.path.join(tmpdir,f) for f in ListFiles().files_db()]
                ListFiles().replace_in_files(list_path,'NAME',self.name)
                shutil.copytree(tmpdir,path_new_catalog)
        except OSError as error:
            print(error)  
    
    def create_module_catalog_local(self):
        """
        Create new local catalog module ,
        first verify if source catalog is valid, 
        second verify the catalog already exist then get path
        for new module catalog and path template data,
        finaly try create the new module folder and extract the data.

        The catalog create in path with call the freya-admin.
        """
        path_new_catalog = os.path.join(self.path,f'Local{self.name}')
        path_tample_files_ = ListFiles().path_files__from_()     
        try: 
            with tempfile.TemporaryDirectory() as tmpdir:
                # create same of inside catalog
                self.path = tmpdir
                self.create_module_catalog()
                # extract setup
                extract_zip = zipfile.ZipFile(path_tample_files_)
                list_names_files = ListFiles().files_local()
                for file_ in list_names_files:
                    extract_zip.extract(file_, tmpdir)
                extract_zip.close()
                list_path_ = [os.path.join(tmpdir,'setup.py')]
                ListFiles().replace_in_files(list_path_,'NAME',self.name)
                shutil.copytree(tmpdir,path_new_catalog)
        except OSError as error:
            print(error)  

    def rename_catalog(self):
        """
        Rename catalog inside Freya
        """
        dir_catalogs = self.path
        try:
            #replace name catalog inside files
            path = os.path.join(dir_catalogs,self.name)
            list_path = [f for f in os.listdir(path) if os.path.isfile(os.path.join(path,f))]
            list_path = [os.path.join(path,f) for f in list_path] # add 
            ListFiles().replace_in_files(list_path,self.name,self.new_name)
            #replace folder name
            path_ = path.split("/")
            path_[-1] = self.new_name
            path_ = "/".join(path_)
            os.rename(path, path_)
        except OSError as error:
            print(error)    
        
    def delete_catalog(self):
        """
        Delete catalog inside Freya
        """
        dir_catalogs = self.path
        try:
            path = os.path.join(dir_catalogs,self.name)
            shutil.rmtree(path)
        except OSError as error:
            print(error)


import tempfile
import os
import Freya_alerce.files # __path__

from unittest import TestCase
from Freya_alerce.files.list_file import ListFiles

class TestListFiles(TestCase):
    

    def setUp(self):
        self.return_files_api = ['configure.py','__init__.py']
        self.return_files_db = ['configure.py','connect.py','__init__.py']
        self.return_files_local = ['setup.py','requirements.txt']
        self.return_path_files_from = os.path.join(Freya_alerce.files.__path__[0],'file_templates','from_.zip')
        self.return_path_files_resource = os.path.join(Freya_alerce.files.__path__[0],'file_templates','newresource.zip')
        

    def test(self):
        self.assertEqual(ListFiles().files_api(), self.return_files_api)
        self.assertEqual(ListFiles().files_db(), self.return_files_db)
        self.assertEqual(ListFiles().files_local(), self.return_files_local)
        self.assertEqual(ListFiles().path_files__from_(), self.return_path_files_from)
        self.assertEqual(ListFiles().path_files_resource(), self.return_path_files_resource)
        
if __name__ == '__main__':
    unittest.main() 


import tempfile
import os
from unittest import TestCase
from Freya_alerce.core.commands.base_freya import Base

class TestDeleteCatalog(TestCase):

    def setUp(self):
        self.tmp_test = tempfile.TemporaryDirectory()

    def test_delete_module_api(self):
        Base(name='test_api',source='api',path=self.tmp_test.name).create_module_catalog()
        path__module_api = os.path.join(self.tmp_test.name,'TEST_API')
        self.assertTrue(os.path.isdir(path__module_api))
        Base(name='test_api',path=self.tmp_test.name).delete_catalog()
        self.assertFalse(os.path.isdir(path__module_api))

    def test_delete_module_db(self):
        Base(name='test_db',source='db',path=self.tmp_test.name).create_module_catalog()
        path__module_db = os.path.join(self.tmp_test.name,'TEST_DB')
        self.assertTrue(os.path.isdir(path__module_db))
        Base(name='test_db',path=self.tmp_test.name).delete_catalog()
        self.assertFalse(os.path.isdir(path__module_db))

    def tearDown(self):
        self.tmp_test.cleanup()

if __name__ == '__main__':
    unittest.main() 


import importlib
import numpy as np

from Freya_alerce.files.verify_file import Verify
from Freya_alerce.core.utils import Utils
from Freya_alerce.catalogs.core.format_lc import FormatLC

"""
Class to get data from module catalog configured in Freya, first check if catalog exist inside Freya
and if not exist try import catalog from local folder. The data get is the all light curves of object in area. Use
degrees (ra,dec,radius) or  the format hh:mm:ss (hh:mm:ss,radius).
"""
class GetData(object):
    """
    Parameters
    -------------------------------------- 
    ra : (float) 
        (degrees) Right Ascension
    dec : (float) 
        (degrees) Declination 
    hms : (string)
        format ICRS
    radius : (float)
        Search radius
    format : (string)
        [numpy,csv,votable]
    catalog: (string)
        Catalog to search
    """

    def __init__(self,radius=0.0002777,format='numpy',nearest=False,**kwargs):
        self.catalog = kwargs.get('catalog').strip().upper()
        #self.catalog = self.catalog.replace(self.catalog[0],self.catalog[0].upper(),1)
        self.ra = kwargs.get('ra')
        self.dec = kwargs.get('dec')
        self.hms = kwargs.get('hms')
        self.radius = radius
        self.format = format
        self.nearest = nearest

        if self.format not in ['csv','votable']:
             return "inadmissible format in consult data"
    

    def generic_call_data(self,call_method):
        """
        Get the LC of catalog called in format CSV/VOTable. 
        Return
        -------
        Columns : ['obj','ra','dec','mjd','mag',''magerr,'filter','catalog'].
            obj : double
                Id of object in catalog
            ra : float
                Right ascension
            dec : float
                Declination
            mjd : float
                Julian day
            mag : float
                Magnitud
            magerr : float
                Magnitud error
            filter : str
                Band
            catalog : str
                Catalog source
        """
        # try :
        """
        Search catalog insiede Freya, if not exist search inside local folder.
        """
        if Verify().verify_catalog_inside(self.catalog):
            module = f'Freya_alerce.catalogs.{self.catalog}.configure'
        elif Verify().verify_catalog_local(self.catalog) :
                module = f'{self.catalog}.configure'

        # Import self.catalog
        mod = importlib.import_module(module)
        # Call class
        class_ =  getattr(mod,f'Configure{self.catalog}') 
        # Call method especific of class
        if call_method == 'get_lc_deg':
            method_ = class_(ra=self.ra,dec=self.dec,radius=self.radius,nearest=self.nearest).get_lc()      
        elif call_method == 'get_lc_hms':
            ra_,dec_ = Utils().hms_to_deg(self.hms)
            method_ = class_(ra=ra_,dec=dec_,radius=self.radius,nearest=self.nearest).get_lc()
        # add catalog source
        column_catalog = np.full(method_.shape[0],self.catalog)
        method_ = np.column_stack((method_, column_catalog))
        # set de estructure return with format
        if self.format == 'numpy':
            return FormatLC(method_).format_numpy()
        elif self.format == 'csv':
            return FormatLC(method_).format_csv()
        elif self.format == 'votable':
            return FormatLC(method_).format_votable()
        # except :
        #     print(f'No find the catalog : {self.catalog}')


import fileinput #replace into files
import os

from Freya_alerce.files.file_templates.path_file_templates import basedir_tf

class ListFiles(object):



    def replace_in_files(self,paths,raplace_word,word):
        """
        Replace a 'word' for 'new word' in specific file.
        Parameters
        ----------
        paths: list
            List of paths of file what replece string.
        relace_word: string
            Original string in file.
        word: string
            New string to replace.
        Return
        ----------

        """
        self.list_path = paths
        self.replace_word = raplace_word
        self.word = word
        for file in self.list_path:
            with fileinput.FileInput(f'{file}', inplace=True) as file_:
                for line in file_:
                    print(line.replace(f'{self.replace_word}', f'{self.word}'), end='')
    
    def files_api(self):
        """
        Get names files use in api.
        Parameters
        ----------
        Return
        ----------
        Return list with name files necessary to extract for api source.
        """
        return ['configure.py','__init__.py']

    def files_db(self):
        """
        Get names files use in data base.
        Parameters
        ----------
        Return
        ----------
        Return list with name files necessary to extract for data base source.
        """
        return ['configure.py','connect.py','__init__.py']

    def files_local(self):
        """
        Get names files use in local catalog.
        Parameters
        ----------
        Return
        ----------
        Return list with name files necessary to extract in local module-catalog.
        """
        return ['setup.py','requirements.txt']

    def path_files__from_(self):
        """
        Get path templeta file from db/api.
        Parameters
        ----------
        Return
        ----------
        Return path of file template for new module-catalog.
        """
        return os.path.join(basedir_tf,'from_.zip')

    def path_files_resource(self):
        """
        Get the path resource generic.
        Parameters
        ----------
        Return
        ----------
        Return path of file template for new resource of and api.
        """
        return os.path.join(basedir_tf,'newresource.zip')



"""
configure.py is the most important file in Freya, this file is called for 
Freya’s core and FreyaAPI’s resources, is the only file you need to modify 
in principle. You need to complete the following methods. When using Freya’s 
method getData, you use this class for calls and depent what method call you 
need use ra and dec or hms, so that's why kwargs is used.
"""

import requests
import io
import numpy as np
from astropy.io import ascii
from astropy.coordinates import SkyCoord
from astropy import units as u

from Freya_alerce.catalogs.core.abstract_catalog import BaseCatalog
from Freya_alerce.core.utils import Utils

class ConfigurePS1(BaseCatalog):
    """
    Parameters:
    ------------
    ra : (float) 
        Right ascension
    dec :  (float) 
        Declination
    radius: (float) 
        Search radius
    nearest: (bool)
        True or False
    """
    def __init__(self,*args,**kwagrs):
        self.ra = kwagrs.get('ra')
        self.dec = kwagrs.get('dec')
        self.radius = kwagrs.get('radius')
        self.nearest = kwagrs.get('nearest')

    def ps1cone(self, format='csv',baseurl="https://catalogs.mast.stsci.edu/api/v0.1/panstarrs", **kw):
            #table="mean",release="dr1",format="csv",columns=None,
        """Do a cone search of the PS1 catalog
        Parameters
        ----------
        """
        data = kw.copy()
        data['ra'] = self.ra
        data['dec'] = self.dec
        data['radius'] = self.radius
        return self.ps1search(format=format,baseurl=baseurl, **data)

    def ps1search(self,format='csv',table="mean",release="dr1",columns=None,baseurl="https://catalogs.mast.stsci.edu/api/v0.1/panstarrs",**kw):
        """Do a general search of the PS1 catalog (possibly without ra/dec/radius)
        
        Parameters
        ----------
        """
        data = kw.copy()
        url = f"{baseurl}/{release}/{table}.{format}"
        data['columns'] = '[{}]'.format(','.join(columns))
        r = requests.get(url, params=data)
        r.raise_for_status()
        # if self.format == "json":
        #     return r.json()
        return r.text

    def ps1ids(self):
        """Get ids (ps1 id) of objects in a radius with respect to ra and dec
        Parameters
        ----------
        """
        constraints = {'nDetections.gt':1}
        columns = ['objID','raMean','decMean']
        results = self.ps1cone(release='dr2',columns=columns,**constraints)

        try:
            results = ascii.read(results)
        except:
            return []

        if self.nearest is True:
            matrix = []
            for re in results:
                matrix.append([re['raMean'],re['decMean']])
            matrix = np.array(matrix)
            return_index = Utils().get_nearest(self.ra,self.dec,matrix)
            temp = []
            temp.append(results[return_index]['objID'])
            return temp

        else :
            return results['objID']

    def filter_id_to_str(self,filer_id):
        id2filter = np.array(list('grizy'))
        filer_str = id2filter[filer_id-1]
        return filer_str

    def ps1curves(self):
        """Get light curves of objects in specific radio with respect ra and dec, and possible return the object most nearest to radio
        Parameters
        ----------
        """
        ps1dic = ''
        first = True
        ids = self.ps1ids()
        if not any(ids):
            ps1dic = 'not found' # not object find
            return ps1dic

        dcolumns = ("""objID, detectID,filterID,obsTime,ra,dec,psfFlux,psfFluxErr,psfMajorFWHM,psfMinorFWHM,
                    psfQfPerfect,apFlux,apFluxErr,infoFlag,infoFlag2,infoFlag3""").split(',') 
        dcolumns = [x.strip() for x in dcolumns]
        dcolumns = [x for x in dcolumns if x and not x.startswith('#')]

        #split ids in dict
        for id in ids:
            dconstraints = {'objID': id}
            dresults = self.ps1search(format ='csv',table='detection',release='dr2',columns=dcolumns,**dconstraints)

            if first :
                dresults_ = ascii.read(dresults)
                filer_str = self.filter_id_to_str(dresults_['filterID'])
                mag = Utils().flux_to_mag(dresults_['psfFlux'])
                magerr = Utils().fluxerr_to_magerr(dresults_['psfFluxErr'],dresults_['psfFlux']) 
                ps1_matrix = np.array([dresults_['objID'],dresults_['ra'],dresults_['dec'],dresults_['obsTime'],mag,magerr,filer_str]).T
                first = False
            #
            else :
                dresults_ = ascii.read(dresults)
                filer_str = self.filter_id_to_str(dresults_['filterID'])
                mag = Utils().flux_to_mag(dresults_['psfFlux'])
                magerr = Utils().fluxerr_to_magerr(dresults_['psfFluxErr'],dresults_['psfFlux']) 
                ps1_matrix_aux = np.array([dresults_['objID'],dresults_['ra'],dresults_['dec'],dresults_['obsTime'],mag,magerr,filer_str]).T
                ps1_matrix = np.vstack((ps1_matrix,ps1_matrix_aux))
        return ps1_matrix

    def get_lc(self):
        """
        Get all ligth curves data or the most close object, inside degree area from PS1 catalog.
        Return
        -------
        Return numpy array 2d with rows represent the objects and columns : ['obj','ra','dec','mjd','mag','magerr,'filter'].
            obj : double
                Id of object in catalog
            ra : float
                Right ascension
            dec : float
                Declination
            mjd : float
                Julian day
            mag : float
                Magnitud
            magerr : float
                Magnitud error
            filter : str
                Band
        """
        data_return = self.ps1curves()
        return data_return


from abc import ABC, abstractmethod

class BaseCatalog(ABC):

    @abstractmethod
    def get_lc():
        """
       Get all ligth curves data or the most close object, inside degree area.

        Return
        -------
        Return numpy array 2d with rows represent the objects and columns : ['obj','ra','dec','mjd','mag','magerr,'filter'].
            obj : double
                Id of object in catalog
            ra : float
                Right ascension
            dec : float
                Declination
            mjd : float
                Julian day
            mag : float
                Magnitud
            magerr : float
                Magnitud error
            filter : str
                Band
        """
        return ""



import tempfile

from unittest import TestCase
from Freya_alerce.files.verify_file import Verify

class TestVerifyFiles(TestCase):
    

    def setUp(self):
        self.valid_source_api = 'api'
        self.valid_source_db = 'db'
        self.valid_source_other = 'other'
        self.valid_source_error_1 = 'cmd'
        self.valid_source_error_2 = 'web/HTPP'

    def test(self):
        self.assertTrue(Verify().verify_source(self.valid_source_api))
        self.assertTrue(Verify().verify_source(self.valid_source_db))
        self.assertTrue(Verify().verify_source(self.valid_source_other))
        self.assertFalse(Verify().verify_source(self.valid_source_error_1))
        self.assertFalse(Verify().verify_source(self.valid_source_error_2))

if __name__ == '__main__':
    unittest.main() 


import tempfile
import os
from unittest import TestCase
from Freya_alerce.core.commands.base_api import BaseAPI


class TestCreateApi(TestCase):
    
    def setUp(self):
        self.temp_FreyaApi = tempfile.TemporaryDirectory()

    def test(self):
        BaseAPI(path=self.temp_FreyaApi.name).create_new_api()
        path_api = os.path.join(self.temp_FreyaApi.name,'FreyaAPI')
        self.assertTrue(os.path.isdir(path_api))

    def tearDown(self):
        self.temp_FreyaApi.cleanup()

if __name__ == '__main__':
    unittest.main() 


import tempfile

from unittest import TestCase
from Freya_alerce.core.utils import Utils

class TestUtilsTransform(TestCase):

    def setUp(self):
        self.test_ra = 139.33444972
        self.test_dec = 68.6350604
        self.test_hms = '09h17m20.26793280000689s +68d38m06.2174s'#+4h34m32.414496000003936s'
        self.test_mag = 14.033394136845427
        self.test_magerr = 0.0012384787365595684

    def test(self):
        #print(Utils().deg_to_hms(self.test_ra,self.test_dec))
        #print(Utils().hms_to_deg(self.test_hms))
        #self.assertEqual(self.test_hms, Utils().deg_to_hms(self.test_ra,self.test_dec))
        self.assertAlmostEqual(self.test_ra, Utils().hms_to_deg(self.test_hms)[0])
        self.assertAlmostEqual(self.test_dec, Utils().hms_to_deg(self.test_hms)[1])
        self.assertEqual(self.test_mag,Utils().flux_to_mag(0.008843869902193546))
        self.assertEqual(self.test_magerr,Utils().fluxerr_to_magerr(1.0087999726238195e-05,0.008843869902193546))
        

if __name__ == '__main__':
    unittest.main() 


from setuptools import setup,find_packages

setup(
      name='Freya_alerce',
      version='0.2.1',
      author='Eric "Jonimott" Fernández',
      author_email='',
      description='Freya is a Python framework that quick development queries in astronomical catalogs and use local or creating easy new API called FreyaAPI',
      url='https://github.com/fernandezeric/Freya',
      license='',
      packages=find_packages(),
      #include_package_data=True,
      package_data = {
            'Freya_alerce.core': ['*.txt'],
            'Freya_alerce.files.file_templates': ['*.zip']
      },
      entry_points = {
            'console_scripts': ['freya-admin=Freya_alerce.freya:Main.main'],
      },
      zip_safe=False,
      classifiers=[
        "Programming Language :: Python :: 3.9",
        "Operating System :: OS Independent",
        "Development Status :: 4 - Beta",
        "Natural Language :: English"
      ],
      test_suite="tests",
      python_requires='>=3.9',
      install_requires=[i.strip() for i in open("requirements.txt").readlines()]
)


import tempfile
import os
from unittest import TestCase
from Freya_alerce.core.commands.base_freya import Base
from Freya_alerce.files.list_file import ListFiles

class TestRenameCatalog(TestCase):

    def setUp(self):
        self.tmp_test = tempfile.TemporaryDirectory()

    def test_rename_api(self):
        Base(name='test',source='api',path=self.tmp_test.name).create_module_catalog()
        path__module = os.path.join(self.tmp_test.name,'TEST')
        self.assertTrue(os.path.isdir(path__module))
        Base(name='test',new_name='test2',path=self.tmp_test.name).rename_catalog()
        path__module = os.path.join(self.tmp_test.name,'TEST2')
        self.assertTrue(os.path.isdir(path__module))

    def test_rename_api(self):
        Base(name='test3',source='db',path=self.tmp_test.name).create_module_catalog()
        path__module = os.path.join(self.tmp_test.name,'TEST3')
        self.assertTrue(os.path.isdir(path__module))
        Base(name='test3',new_name='test4',path=self.tmp_test.name).rename_catalog()
        path__module = os.path.join(self.tmp_test.name,'TEST4')
        self.assertTrue(os.path.isdir(path__module))

    def tearDown(self):
        self.tmp_test.cleanup()

if __name__ == '__main__':
    unittest.main() 